registered_event_handler

Macro registered_event_handler 

macro_rules! registered_event_handler {
    ($interest:expr, $event_type: ident, $getter: ident, $setter: ident) => { ... };
}
Similar to event_handler!, but also registers/unregisters a [ConstellationInterest] with the global scope when the handler is set or cleared. Use this macro for event handlers whose corresponding events are sent by the constellation only to interested pipelines.